@@ -1,5 +1,5 @@
 # ==============================================================================
-# Copyright 2019 Nikolai Bartenev. Contacts: botfgbartenevfgzero76@gmail.com
+# Copyright 2020 Nikolai Bartenev. Contacts: botfgbartenevfgzero76@gmail.com
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,13 +19,12 @@ import getpass
 import os
 import sys
 from datetime import date, datetime
-
+import configparser
 
 import numpy
 import pyAesCrypt
 from pysqlcipher3 import dbapi2 as sqlcipher
 
-
 class color:
     OKBLUE = ('\033[94m')
     OKGREEN = ('\033[92m')
@@ -33,9 +32,11 @@ class color:
     RED = ('\033[91m')
     END = ('\033[0m')
 
-botdrPrompt = ("BotDr ~# ")
 
-botdrlogo = (color.OKGREEN + '''
+botdrPrompt = (color.OKGREEN + "BotDr ~# " + color.END)
+
+
+botdrlogo = (color.OKGREEN + r'''
     ____        __     ____      
    / __ )____  / /_   / __ \_____
   / __  / __ \/ __/  / / / / ___/
@@ -44,7 +45,19 @@ botdrlogo = (color.OKGREEN + '''
 ''' + color.END)
 
 
-db_dir = ('/home/usr/.local/lib/python3.6/site-packages/BotDr/')
+db_dir = ('/home/{}/.botdr/'.format(getpass.getuser()))
+
+
+papka = os.path.isdir(db_dir)
+if papka == False:
+    os.mkdir(db_dir)
+    
+    
+def crypt_aes(file, password) -> None:
+    buffer_size = 512 * 2048
+    pyAesCrypt.encryptFile(file, str(file + '.aes'), password, buffer_size)
+    os.remove(file)
+
 
 def clearScr() -> None:
     os.system('clear')
@@ -54,116 +67,199 @@ def dec(string: str) -> str:
     length_string = (44 - len(string)) // 2     # 34
     decor = str((length_string * '-') + string + (length_string * '-') + '\n')
     return decor
-    
+
+
+def createConfig(path):
+    #Create a config file
+    config = configparser.ConfigParser()
+    config.add_section("Settings")
+    config.set("Settings", "accounts status", "off")
+    with open(path, "w") as config_file:
+        config.write(config_file)
+    config_file.close()
+
 
 def vhod() -> None:
     global account_name, account_pass, conn, cursor
-    clearScr()
-    print(botdrlogo)
-    print('enter Q to go to the main menu\n')
-    print(dec(color.RED + 'Login' + color.END))
-    print(color.RED +'1' + color.END + ')--' + color.OKBLUE + 'sign up' + color.END)
-    print(color.RED +'2' + color.END + ')--' + color.OKBLUE + 'sign in' + color.END)
-    print(color.RED +'3' + color.END + ')--' + color.OKBLUE + 'exit\n' + color.END)
-    u_a = input(botdrPrompt)
-    if u_a == '3':
-        clearScr()
-        sys.exit()
-    elif u_a == '1':
+    path = (db_dir + "botdr.ini")
+    config = configparser.ConfigParser()
+    config.read(path)
+    accounts_status = config.get("Settings", "accounts status")
+    if accounts_status == "on":
         clearScr()
         print(botdrlogo)
-        print(dec(color.RED + 'sign up' + color.END))
-        # check account_existence
-        while True:
-            account_name = input(color.OKBLUE + 'login: ' + color.END)
-            if account_name == 'Q':
-                vhod()
-            elif len(account_name) < 3:
-                print(color.RED + 'login length must be more than 3 characters' + color.END)
-                continue
-            x1 = os.path.isfile(db_dir + account_name + '.db')
-            if x1:
-                print(color.RED + 'an account with that name already exists' + color.END)
-            elif not x1:
-                break
-        # end check account_existence
-        while True:
-            password1 = getpass.getpass(color.OKBLUE + 'enter password: ' + color.END)
-            if password1 == 'Q':
-                vhod()
-            elif password1 == account_name:
-                print(color.RED + 'login cannot be a password' + color.END)
-            else:
-                break
-        password2 = getpass.getpass(color.OKBLUE + 'repeat password: ' + color.END)
-        if password2 == 'Q':
-            vhod()
-        while True:
-            if password1 == password2:
-                account_pass = password1
-                break
-            elif password1 != password2:
-                print(color.RED + 'different passwords' + color.END)
-                password1 = getpass.getpass(color.OKBLUE + 'enter password: ' + color.END)
-                password2 = getpass.getpass(color.OKBLUE + 'repeat password: ' + color.END)
-                if password1 or password2 == 'Q':
-                    vhod()
-        while True:
-            u_podtver = input(color.OKBLUE + '[Y/n] add ' + color.END + account_name + ': ')
-            if u_podtver == 'n':
-                vhod()
-                break
-            elif u_podtver == 'Y':
-                # make users db
-                name_db = db_dir + account_name + '.db'
-                conn = sqlcipher.connect(name_db)
-                cursor = conn.cursor()
-                cursor.execute("PRAGMA key={}".format(account_pass))
-                cursor.execute("""CREATE TABLE users
-                    ( name text NOT NULL, bday datetime NOT NULL)
-                        """)
-                conn.commit()
-                break
-            else:
-                print(color.RED + 'wrong command' + color.END)
-    elif u_a == '2':
-        clearScr()
-        print(botdrlogo)
-        print(dec(color.RED + 'sign in' + color.END))
-        # check account_existence
-        while True:
-            account_name = input(color.OKBLUE + 'login: ' + color.END)
-            if account_name == 'Q':
-                vhod()
-            x = os.path.isfile(db_dir + account_name + '.db')
-            if x:
-                break
-            elif not x:
-                print(color.RED +  'account with this name was not found' + color.END)
+        print('enter Q to go to the main menu\n')
+        print(dec(color.RED + 'Login' + color.END))
+        print(color.RED +'1' + color.END + ')--' + color.OKBLUE + 'sign up' + color.END)
+        print(color.RED +'2' + color.END + ')--' + color.OKBLUE + 'sign in' + color.END)
+        print(color.RED +'3' + color.END + ')--' + color.OKBLUE + 'exit\n' + color.END)
+        u_a = input(botdrPrompt)
+        if u_a == '3':
+            clearScr()
+            sys.exit()
+        elif u_a == '1':
+            clearScr()
+            print(botdrlogo)
+            print(dec(color.RED + 'sign up' + color.END))
+            # check account_existence
+            while True:
+                account_name = input(color.OKBLUE + 'login: ' + color.END)
                 if account_name == 'Q':
                     vhod()
-        # end check account_existence
-        name_db = db_dir + account_name + '.db'
-        conn = sqlcipher.connect(name_db)
-        cursor = conn.cursor()
-        clearScr()
-        print(botdrlogo)
-        print(dec(color.RED + 'sign in ' + color.END + account_name))
-        while True:
-            try:
-                account_pass = getpass.getpass(color.OKBLUE + 'enter password: ' + color.END)
-                if account_pass == 'Q':
+                elif account_name == 'main_botdr.db':
+                    print(color.RED + 'invalid name' + color.END)
+                    continue
+                elif len(account_name) < 3:
+                    print(color.RED + 'login length must be more than 3 characters' + color.END)
+                    continue
+                x1 = os.path.isfile(db_dir + account_name + '.db')
+                if x1:
+                    print(color.RED + 'an account with that name already exists' + color.END)
+                elif not x1:
+                    break
+            # end check account_existence
+            while True:
+                password1 = getpass.getpass(color.OKBLUE + 'enter password: ' + color.END)
+                if password1 == 'Q':
                     vhod()
-                cursor.execute("PRAGMA key={}".format(account_pass))
-                cursor.execute('SELECT COUNT(name) FROM users')
-            except:
-                print(color.RED + 'wrong password' + color.END)
-            else:
-                break
-    else:
-        #print('wrong command')
-        vhod()
-
+                elif password1 == account_name:
+                    print(color.RED + 'login cannot be a password' + color.END)
+                else:
+                    break
+            password2 = getpass.getpass(color.OKBLUE + 'repeat password: ' + color.END)
+            if password2 == 'Q':
+                vhod()
+            while True:
+                if password1 == password2:
+                    account_pass = password1
+                    break
+                elif password1 != password2:
+                    print(color.RED + 'different passwords' + color.END)
+                    password1 = getpass.getpass(color.OKBLUE + 'enter password: ' + color.END)
+                    password2 = getpass.getpass(color.OKBLUE + 'repeat password: ' + color.END)
+                    if password1 or password2 == 'Q':
+                        vhod()
+            while True:
+                u_podtver = input(color.OKBLUE + '[Y/n] add ' + color.END + account_name + ': ')
+                if u_podtver == 'n':
+                    vhod()
+                    break
+                elif u_podtver == 'Y':
+                    # make users db
+                    name_db = (db_dir + account_name + '.db')
+                    conn = sqlcipher.connect(name_db)
+                    cursor = conn.cursor()
+                    cursor.execute("PRAGMA key={}".format(account_pass))
+                    cursor.execute("""CREATE TABLE users
+                        ( id integer primary key, name varchar(255) NOT NULL, bday datetime NOT NULL)
+                            """)
+                    conn.commit()
+                    break
+                else:
+                    print(color.RED + 'wrong command' + color.END)
+        elif u_a == '2':
+            clearScr()
+            print(botdrlogo)
+            print(dec(color.RED + 'sign in' + color.END))
+            # check account_existence
+            while True:
+                account_name = input(color.OKBLUE + 'login: ' + color.END)
+                if account_name == 'Q':
+                    clearScr()
+                    sys.exit()
+                x = os.path.isfile(db_dir + account_name + '.db')
+                if x:
+                    break
+                elif not x:
+                    print(color.RED +  'account with this name was not found' + color.END)
+                    if account_name == 'Q':
+                        vhod()
+            # end check account_existence
+            name_db = (db_dir + account_name + '.db')
+            conn = sqlcipher.connect(name_db)
+            cursor = conn.cursor()
+            clearScr()
+            print(botdrlogo)
+            print(dec(color.RED + 'sign in ' + color.END + account_name))
+            while True:
+                try:
+                    account_pass = getpass.getpass(color.OKBLUE + 'enter password: ' + color.END)
+                    if account_pass == 'Q':
+                        vhod()
+                    cursor.execute("PRAGMA key={}".format(account_pass))
+                    cursor.execute('SELECT COUNT(name) FROM users')
+                except:
+                    print(color.RED + 'wrong password' + color.END)
+                else:
+                    break
+        else:
+            #print('wrong command')
+            vhod()
+    elif accounts_status == "off":
+        clearScr()
+        x1 = os.path.isfile(db_dir + 'main_botdr.db')
+        if x1 == False:
+            print(botdrlogo)
+            print('enter Q to go to the main menu\n')
+            print(dec(color.RED + 'sign up' + color.END))
+            while True:
+                password1 = getpass.getpass(color.OKBLUE + 'enter password: ' + color.END)
+                if password1 == 'Q':
+                    clearScr()
+                    sys.exit()
+                else:
+                    break
+            password2 = getpass.getpass(color.OKBLUE + 'repeat password: ' + color.END)
+            if password2 == 'Q':
+                vhod()
+            while True:
+                if password1 == password2:
+                    account_pass = password1
+                    break
+                elif password1 != password2:
+                    print(color.RED + 'different passwords' + color.END)
+                    password1 = getpass.getpass(color.OKBLUE + 'enter password: ' + color.END)
+                    password2 = getpass.getpass(color.OKBLUE + 'repeat password: ' + color.END)
+                    if password1 or password2 == 'Q':
+                        vhod()
+            while True:
+                u_podtver = input(color.OKBLUE + '[Y/n] add account: ' + color.END)
+                if u_podtver == 'n':
+                    vhod()
+                    break
+                elif u_podtver == 'Y':
+                    # make users db
+                    name_db = (db_dir + 'main_botdr.db')
+                    conn = sqlcipher.connect(name_db)
+                    cursor = conn.cursor()
+                    cursor.execute("PRAGMA key={}".format(account_pass))
+                    cursor.execute("""CREATE TABLE users
+                        ( id integer primary key, name varchar(255) NOT NULL, bday datetime NOT NULL)
+                            """)
+                    conn.commit()
+                    break
+                else:
+                    print(color.RED + 'wrong command' + color.END)        
+        if x1 == True:
+            name_db = (db_dir + 'main_botdr.db')
+            conn = sqlcipher.connect(name_db)
+            cursor = conn.cursor()
+            clearScr()
+            print(botdrlogo)
+            print(dec(color.RED + 'sign in ' + color.END))
+            while True:
+                try:
+                    account_pass = getpass.getpass(color.OKBLUE + 'enter password: ' + color.END)
+                    if account_pass == 'Q':
+                        vhod()
+                    cursor.execute("PRAGMA key={}".format(account_pass))
+                    cursor.execute('SELECT COUNT(name) FROM users')
+                except:
+                    print(color.RED + 'wrong password' + color.END)
+                else:
+                    break
+    
+    
 
 def main() -> None:
     global account_name, account_pass, cursor, conn
@@ -171,13 +267,13 @@ def main() -> None:
     print(botdrlogo)
     print(dec(color.RED + 'options' + color.END))
     # soon dr
-    cursor.execute("""select cast (julianday(
+    cursor.execute("""select cast ((julianday(
             case
                 when strftime('%m-%d', bday) < strftime('%m-%d', 'now')
                 then strftime('%Y-', 'now', '+1 year')
                 else strftime('%Y-', 'now')
             end || strftime('%m-%d', bday)
-        )-julianday('now') as int) as tillbday from users""")
+        )-julianday('now')) + 1 as int) as tillbday from users""")
     results = numpy.array(cursor.fetchall(), dtype=int)
     birth_in_mounth = 0
     now = datetime.now()
@@ -188,26 +284,27 @@ def main() -> None:
     print(color.RED + 'dr' + color.END + ')--' + color.OKBLUE +  'YIEW This month birthday: ' + color.END + str(birth_in_mounth))
     # end soon dr
     print(color.RED + '\n1' + color.END + ')--' + color.OKBLUE + 'ADD' + color.END)
-    print(color.RED + '2' + color.END + ')--' + color.OKBLUE + 'YIEW: ' + color.END + str(len(results)))
+    print(color.RED + '2' + color.END + ')--' + color.OKBLUE + 'YIEW:' + color.END + str(len(results)))
     print(color.RED + '3' + color.END + ')--' + color.OKBLUE + 'DELETE' + color.OKBLUE)
     print(color.RED + '4' + color.END + ')--' + color.OKBLUE + 'DELETE ALL' + color.END)
     print(color.RED + '5' + color.END + ')--' + color.OKBLUE + 'EDIT' + color.END)
     print(color.RED + '6' + color.END + ')--' + color.OKBLUE + 'STATISTICS' + color.END)
     print(color.RED + '7' + color.END + ')--' + color.OKBLUE + 'ACCOUNT ACTIONS' + color.END)
     print(color.RED + '8' + color.END + ')--' + color.OKBLUE + 'SEARCH' + color.END)
+    print(color.RED + '9' + color.END + ')--' + color.OKBLUE + 'SETTINGS' + color.END)
     print(color.RED + 'Q' + color.END + ')--' + color.OKBLUE + 'EXIT\n' + color.END)
     usercomand = input(botdrPrompt)
     clearScr()
     if usercomand == "dr":
         print(botdrlogo)
         print(dec(color.RED + 'Birthday in this month: ' + color.END + str(birth_in_mounth))) 
-        cursor.execute("""select name, bday, cast (julianday(
+        cursor.execute("""select name, bday, cast ((julianday(
             case
                 when strftime('%m-%d', bday) < strftime('%m-%d', 'now')
                 then strftime('%Y-', 'now', '+1 year')
                 else strftime('%Y-', 'now')
-            end || strftime('%m-%d', bday)
-        )-julianday('now') as int) as tillbday, cast (julianday(
+            end || strftime('%m-%d', bday, '+1 day')
+        )-julianday('now')) int) as tillbday, cast (julianday(
             case
                 when strftime('%m-%d', bday) > strftime('%m-%d', 'now')
                 then strftime('%Y-', 'now') - strftime('%Y-', bday)
@@ -282,13 +379,13 @@ def main() -> None:
         results = numpy.array(cursor.fetchall(), dtype=str)
         if not results.size:
             main()
-        cursor.execute("""select name, bday, cast (julianday(
+        cursor.execute("""select name, bday, cast ((julianday(
             case
                 when strftime('%m-%d', bday) < strftime('%m-%d', 'now')
                 then strftime('%Y-', 'now', '+1 year')
                 else strftime('%Y-', 'now')
-            end || strftime('%m-%d', bday)
-        )-julianday('now') as int) as tillbday, cast (julianday(
+            end || strftime('%m-%d', bday, '+1 day')
+        )-julianday('now')) as int) as tillbday, cast (julianday(
             case
                 when strftime('%m-%d', bday) > strftime('%m-%d', 'now')
                 then strftime('%Y-', 'now') - strftime('%Y-', bday)
@@ -310,13 +407,13 @@ def main() -> None:
         print(botdrlogo)
         print(dec(color.RED + 'Delete all' + color.END))
         cursor.execute("PRAGMA key={}".format(account_pass))
-        cursor.execute("""select name, bday, cast (julianday(
+        cursor.execute("""select name, bday, cast ((julianday(
             case
                 when strftime('%m-%d', bday) < strftime('%m-%d', 'now')
                 then strftime('%Y-', 'now', '+1 year')
                 else strftime('%Y-', 'now')
-            end || strftime('%m-%d', bday)
-        )-julianday('now') as int) as tillbday, cast (julianday(
+            end || strftime('%m-%d', bday, '+1 day')
+        )-julianday('now')) as int) as tillbday, cast (julianday(
             case
                 when strftime('%m-%d', bday) > strftime('%m-%d', 'now')
                 then strftime('%Y-', 'now') - strftime('%Y-', bday)
@@ -327,19 +424,17 @@ def main() -> None:
         if not results.size:
             main()
         elif results.size > 0:
-            cursor.close
             while True:
                 uc = input(color.OKBLUE + 'Delete all person? [Y/n]: ' + color.END)
                 if uc == 'Y':
                     break
                 elif uc == 'n':
                     main()
-                else:
-                    print(color.RED + 'Wrong command' + color.END)
             while True:
                 account_pass = getpass.getpass(color.OKBLUE + 'Enter password: ' + color.END)
+                if account_pass == "Q":
+                    main()
                 try:
-                    conn.close
                     cursor.execute("PRAGMA key={}".format(account_pass))
                     cursor.execute('SELECT COUNT(name) FROM users')
                 except:
@@ -354,19 +449,19 @@ def main() -> None:
         print(botdrlogo)
         print(dec(color.RED + 'Delete' + color.END))
         while True:
-            print('show everyone? [Y/n]\n')
+            print(color.OKBLUE + 'show everyone? [Y/n]\n' + color.END)
             uc = input(botdrPrompt)
             if uc == 'Y':
                 clearScr()
                 print(botdrlogo)
                 print(dec(color.RED + 'Delete' + color.END))
-                cursor.execute("""select name, bday, cast (julianday(
+                cursor.execute("""select name, bday, cast ((julianday(
                     case
                         when strftime('%m-%d', bday) < strftime('%m-%d', 'now')
                         then strftime('%Y-', 'now', '+1 year')
                         else strftime('%Y-', 'now')
-                    end || strftime('%m-%d', bday)
-                )-julianday('now') as int) as tillbday, cast (julianday(
+                    end || strftime('%m-%d', bday, '+1 day')
+                )-julianday('now')) as int) as tillbday, cast (julianday(
                     case
                         when strftime('%m-%d', bday) > strftime('%m-%d', 'now')
                         then strftime('%Y-', 'now') - strftime('%Y-', bday)
@@ -404,9 +499,8 @@ def main() -> None:
             while True:
                 try:
                     account_pass = getpass.getpass(color.OKBLUE + 'Enter password: ' + color.END)
-                    if account_name == 'Q':
+                    if account_pass == 'Q':
                         main()
-                    conn.close
                     cursor.execute("PRAGMA key={}".format(account_pass))
                     cursor.execute('SELECT COUNT(name) FROM users')
                 except:
@@ -423,19 +517,19 @@ def main() -> None:
         cursor.execute('select count(name) from users')
         results2 = cursor.fetchone()
         while True:
-            print('\nshow everyone?\n')
+            print(color.OKBLUE + 'show everyone? [Y/n]\n' + color.END)
             uc = input(botdrPrompt)
             if uc == 'Y':
                 clearScr()
                 print(botdrlogo)
                 print(dec(color.RED + 'Edit' + color.END))
-                cursor.execute("""select name, bday, cast (julianday(
+                cursor.execute("""select name, bday, cast ((julianday(
                     case
                         when strftime('%m-%d', bday) < strftime('%m-%d', 'now')
                         then strftime('%Y-', 'now', '+1 year')
                         else strftime('%Y-', 'now')
-                    end || strftime('%m-%d', bday)
-                )-julianday('now') as int) as tillbday, cast (julianday(
+                    end || strftime('%m-%d', bday, '+1 day')
+                )-julianday('now')) as int) as tillbday, cast (julianday(
                     case
                         when strftime('%m-%d', bday) > strftime('%m-%d', 'now')
                         then strftime('%Y-', 'now') - strftime('%Y-', bday)
@@ -445,7 +539,7 @@ def main() -> None:
                 results = numpy.array(cursor.fetchall(), dtype=str)
                 for item in results:
                     print(color.OKBLUE + 'Name: ' + color.END + item[0] + color.OKBLUE + ' date of birth: ' + color.END + item[1].replace('-', '.'))
-                    print(color.OKBLUE + 'In ' + color.END + item[2] + color.OKBLUE + ' days it will be ' + color.END + item[3] + color.OKBLUE + ' years' + color.END)
+                    print(color.OKBLUE + 'In ' + color.END + item[2] + color.OKBLUE + ' days it will be ' + color.END + item[3] + color.OKBLUE + ' years\n' + color.END)
                 break
             elif uc == 'n':
                 break
@@ -469,7 +563,7 @@ def main() -> None:
             sql = ('SELECT * FROM users WHERE name = ?')
             cursor.execute(sql, (uc_name,))
             results = cursor.fetchone()
-            print(color.OKBLUE + 'Name: ' + color.END + str(results[0]) + color.OKBLUE + ' birth date: ' + color.END + str(results[1]))
+            print(color.OKBLUE + 'Name: ' + color.END + str(results[1]) + color.OKBLUE + ' birth date: ' + color.END + str(results[2]))
             while True:
                 print(color.RED + '\n1' + color.END + ')--' + color.OKBLUE + 'Edit name' + color.END)
                 print(color.RED + '2' + color.END + ')--' + color.OKBLUE + 'Edit date\n' + color.END)
@@ -499,7 +593,7 @@ def main() -> None:
                         if account_pass == 'Q':
                             main()
                         try:
-                            conn.close
+                            conn.close()
                             cursor.execute("PRAGMA key={}".format(account_pass))
                             cursor.execute('SELECT COUNT(name) FROM users')
                         except:
@@ -531,7 +625,7 @@ def main() -> None:
                         if account_pass == 'Q':
                             main()
                         try:
-                            conn.close
+                            conn.close()
                             cursor.execute("PRAGMA key={}".format(account_pass))
                             cursor.execute('SELECT COUNT(name) FROM users')
                         except:
@@ -565,13 +659,13 @@ def main() -> None:
                     year = 366
             else:
                 year = 365
-            cursor.execute("""select cast (julianday(
+            cursor.execute("""select cast ((julianday(
                 case
                     when strftime('%m-%d', bday) < strftime('%m-%d', 'now')
                     then strftime('%Y-', 'now', '+1 year')
                     else strftime('%Y-', 'now')
-                end || strftime('%m-%d', bday)
-            )-julianday('now') as int) as tillbday, cast (julianday(
+                end || strftime('%m-%d', bday, '+1 day')
+            )-julianday('now')) as int) as tillbday, cast (julianday(
                 case
                     when strftime('%m-%d', bday) > strftime('%m-%d', 'now')
                     then strftime('%Y-', 'now') - strftime('%Y-', bday)
@@ -584,7 +678,7 @@ def main() -> None:
                 if (year - int(i[0])) < int(i[0]):
                     dr_in_this_year += 1
             print(color.OKBLUE + 'total people: ' + color.END + str(results2[0]))
-            mas_year = list(int(i[1]) - 1 for i in results)
+            mas_year = [int(i[1]) - 1 for i in results]
             avg = int(sum(mas_year)//len(mas_year))
             print(color.OKBLUE + 'average age: ' + color.END + str(avg))
             print(color.OKBLUE + 'birthdays this year: ' + color.END + str(dr_in_this_year))
@@ -606,7 +700,7 @@ def main() -> None:
             print(color.RED + '4' + color.END + ')--' + color.OKBLUE + 'Sign out\n' + color.END)
             uc = input(botdrPrompt)
             if uc == '4':  # 4-sign out
-                conn.close
+                conn.close()
                 vhod()
                 break
             elif uc == 'Q':
@@ -620,7 +714,7 @@ def main() -> None:
                         account_pass = getpass.getpass(color.OKBLUE + 'Enter password: ' + color.END)
                         if account_pass == 'Q':
                             main()
-                        conn.close
+                        conn.close()
                         cursor.execute("PRAGMA key={}".format(account_pass))
                         cursor.execute('SELECT COUNT(name) FROM users')
                     except:
@@ -632,8 +726,8 @@ def main() -> None:
                     if uc == 'n':
                         break
                     elif uc == 'Y':
-                        cursor.close
-                        conn.close
+                        cursor.close()
+                        conn.close()
                         os.remove(db_dir + account_name + '.db')
                         vhod()
                         main()
@@ -650,7 +744,7 @@ def main() -> None:
                         account_pass = getpass.getpass(color.OKBLUE + 'Enter password: ' + color.END)
                         if account_pass == 'Q':
                             main()
-                        conn.close
+                        conn.close()
                         cursor.execute("PRAGMA key={}".format(account_pass))
                         cursor.execute('SELECT COUNT(name) FROM users')
                     except:
@@ -695,7 +789,7 @@ def main() -> None:
                         account_pass = getpass.getpass(color.OKBLUE + 'Enter password: ' + color.END)
                         if account_pass == 'Q':
                             main()
-                        conn.close
+                        conn.close()
                         cursor.execute("PRAGMA key={}".format(account_pass))
                         cursor.execute('SELECT COUNT(name) FROM users')
                     except:
@@ -809,15 +903,15 @@ def main() -> None:
                         print(dec(color.RED + 'Import csv' + color.END))
                         uc = input(color.OKBLUE + 'Is the file encrypted? [Y/n]: ' + color.END)
                         if uc == 'Q':
-                            main
+                            main()
                         elif uc == 'n':
                             while True:
                                 name_dir = input(color.OKBLUE + 'Enter dir: ' + color.END)
-                                if name_export == 'Q':
+                                if name_dir == 'Q':
                                     main()                 
-                                if len(name_export) == 0:
+                                if len(name_dir) == 0:
                                     print(color.RED + 'Incorrect name' + color.END)
-                                elif len(name_export) > 0:
+                                elif len(name_dir) > 0:
                                     break
                                 x1 = os.path.isdir(name_dir)
                                 if x1:
@@ -840,7 +934,7 @@ def main() -> None:
                             results = numpy.array(cursor.fetchall(), dtype=str)
                             with open(name_dir + '/' + file, "r") as f_obj:
                                 reader = csv.reader(f_obj)
-                                incorrect_import_csv = list()
+                                incorrect_import_csv = []
                                 for row in reader:
                                     if len(row) == 2:
                                         if row[0] in results:
@@ -866,11 +960,11 @@ def main() -> None:
                         elif uc == 'Y':
                             while True:
                                 name_dir = input(color.OKBLUE + 'Enter dir: ' + color.END)
-                                if name_export == 'Q':
+                                if name_dir == 'Q':
                                     main()                 
-                                if len(name_export) == 0:
+                                if len(name_dir) == 0:
                                     print(color.RED + 'Incorrect name' + color.END)
-                                elif len(name_export) > 0:
+                                elif len(name_dir) > 0:
                                     break
                                 x1 = os.path.isdir(name_dir)
                                 if x1:
@@ -904,7 +998,7 @@ def main() -> None:
                             results = numpy.array(cursor.fetchall(), dtype=str)
                             with open(name_dir + '/' + file2, "r") as f_obj:
                                 reader = csv.reader(f_obj)
-                                incorrect_import_csv = list()
+                                incorrect_import_csv = []
                                 for row in reader:
                                     if len(row) == 2:
                                         if row[0] in results:
@@ -935,6 +1029,7 @@ def main() -> None:
                 print(color.RED + 'Wrong command' + color.END)
         main()
     elif usercomand == '8':
+        clearScr()
         print(botdrlogo)
         print(dec(color.RED + 'Search' + color.END))
         cursor.execute('select count(name) from users')
@@ -955,13 +1050,13 @@ def main() -> None:
                     print(dec(color.RED + 'Search' + color.END))
                 elif results[0] == 1:
                     break
-            sql = ("""select name, bday, cast (julianday(
+            sql = ("""select name, bday, cast ((julianday(
                 case
                     when strftime('%m-%d', bday) < strftime('%m-%d', 'now')
                     then strftime('%Y-', 'now', '+1 year')
                     else strftime('%Y-', 'now')
-                end || strftime('%m-%d', bday)
-            )-julianday('now') as int) as tillbday, cast (julianday(
+                end || strftime('%m-%d', bday, '+1 day')
+            )-julianday('now')) as int) as tillbday, cast (julianday(
                 case
                     when strftime('%m-%d', bday) > strftime('%m-%d', 'now')
                     then strftime('%Y-', 'now') - strftime('%Y-', bday)
@@ -986,6 +1081,79 @@ def main() -> None:
                 print(dec(color.RED + 'Search' + color.END))
                 print(color.OKBLUE + 'Name: ' + color.END + item[0] + color.OKBLUE + ' date of birth: ' + color.END + item[1].replace('-', '.'))
                 print(color.OKBLUE + 'In ' + color.END + item[2] + color.OKBLUE + ' days it will be ' + color.END + item[3] + color.OKBLUE + ' years\n' + color.END)
+        elif results[0] == 0:
+           main()         
+    elif usercomand == '9': # settings
+        while True:
+            clearScr()
+            print(botdrlogo)
+            print(dec(color.RED + 'Settings' + color.END))
+            path = (db_dir + "botdr.ini")
+            if not os.path.exists(path):
+                createConfig(path)
+            config = configparser.ConfigParser()
+            config.read(path)
+            accounts_status = config.get("Settings", "accounts status")
+            print(color.RED + '1' + color.END + ')--' + color.OKBLUE + 'on/off accounts status: ' + color.END + color.OKGREEN + accounts_status + color.END)
+            print(color.RED + '2' + color.END + ')--' + color.OKBLUE + 'info' + color.END)
+            while True:
+                print(color.RED + '\nQ)--GO BACK\n' + color.END)
+                uc = input(botdrPrompt)
+                if uc == '1':
+                    if accounts_status == 'off':
+                        config.set("Settings", "accounts status", "on")
+                        clearScr()
+                        print(botdrlogo)
+                        print(dec(color.RED + 'Accounts status' + color.END))
+                        while True:
+                            new_account_name = input(color.OKBLUE + 'enter a new login for the main account: ' + color.END)
+                            x1 = os.path.isfile(new_account_name)
+                            if new_account_name == "Q":
+                                main()
+                            elif len(new_account_name) < 3:
+                                print(color.RED + 'login length must be more than 3 characters' + color.END)
+                            elif x1 == True:
+                                print(color.RED + 'an account with that name already exists' + color.END)
+                            else:
+                                break
+                        os.rename(db_dir + 'main_botdr.db', db_dir + str(new_account_name) + '.db')
+                        config.set("Settings", "accounts status", "on")
+                    elif accounts_status == 'on':
+                        clearScr()
+                        print(botdrlogo)
+                        print(dec(color.RED + 'Accounts status' + color.END))
+                        while True:
+                            new_account_name = input(color.OKBLUE + 'choose which account to make the main: ' + color.END)
+                            x1 = os.path.isfile(new_account_name)
+                            if new_account_name == "Q":
+                                main()
+                            elif len(new_account_name) == 0 or x1 == False:
+                                print(color.RED + 'account not found' + color.END)
+                            else:
+                                break
+                        os.rename(db_dir + str(new_account_name) + '.db', db_dir + 'main_botdr.db')
+                        config.set("Settings", "accounts status", "off")
+                    with open(path, "w") as config_file:
+                        config.write(config_file)
+                    config_file.close()
+                    main()
+                elif uc == '2':
+                    clearScr()
+                    print(botdrlogo)
+                    print(dec(color.RED + 'Info' + color.END))
+                    print(color.OKGREEN + 'version: ' + color.END + '1.4.1.3')
+                    print(color.OKGREEN + 'license: ' + color.END + 'Apache License Version 2.0')
+                    print(color.OKGREEN + 'author: ' + color.END + 'botfg76')
+                    print(color.OKGREEN + 'author email: ' + color.END + 'botfgbartenevfgzero76@gmail.com')
+                    while True:
+                        print(color.RED + '\nQ)--GO BACK\n' + color.END)
+                        uc_name = input(botdrPrompt)
+                        if uc_name == 'Q':
+                            main()
+                            break
+                elif uc == 'Q':
+                    main()
+                    break    
     elif usercomand == 'Q':  # Q-exit
         cursor.close()
         clearScr()
@@ -993,9 +1161,14 @@ def main() -> None:
     else:
         main()
 
-def super_main() -> None:
-    x1 = os.path.isdir('/usr/share/BotDr')
-    if not x1:
-        os.mkdir('/usr/share/BotDr')
+
+def super_main():
+    path = (db_dir + "botdr.ini")
+    if not os.path.exists(path):
+        createConfig(path)
     vhod()
-    main()
\ No newline at end of file
+    main()
+
+
+
+#super_main()
